@@ -1,6 +1,6 @@
 from pyfiglet import Figlet
 import argparse
-from OntimDevTool import version
+from OntimDevTool import G_version
 from OntimDevTool.diag_port_controller import open_diag_port, close_diag_port
 from OntimDevTool.auth_controller import authorise, edl, offline_auth_01_get_nonce, offline_auth_02_get_sign, offline_auth_03_set_permission
 
@@ -8,8 +8,8 @@ FUNCTIONLIST = ["open_diag", "close_diag", "authorise", "edl",
                 "offline_auth_01_get_nonce", "offline_auth_02_get_sign", "offline_auth_03_set_permission"]
 
 def print_logo():
-    logo = Figlet().renderText(f"Ontim Tool      {version}")
-    # logo = f"Ontim Tool      {version}"
+    # logo = Figlet().renderText(f"Ontim Tool      {version}")
+    logo = f"Ontim Tool      {G_version}"
     print(logo)
 
 def main():
@@ -55,6 +55,8 @@ def main():
 
     if args.project:
         project = args.project
+    else:
+        project = "sunfire"
 
     if args.function:
         function = args.function
@@ -70,9 +72,9 @@ def function_hub(project, function, offline_para):
     elif function == FUNCTIONLIST[1]:
         close_diag_port()
     elif function == FUNCTIONLIST[2]:
-        authorise()
+        authorise(project)
     elif function == FUNCTIONLIST[3]:
-        edl()
+        edl(project)
     elif function == FUNCTIONLIST[4]:
         offline_auth_01_get_nonce()
     elif function == FUNCTIONLIST[5]:
